///////////////////////////////////////////////////////////////////////////////
// GroupNameList.m
// ===============
// DataSource class for NSTableView
// Connect it to "dataSource" and "delegate" outlets of NSOutlineView in IB.
//
// This DataSource class holds the list of group names in "rows" (NSMutableArray).
//
//  AUTHOR: Song Ho Ahn (song.ahn@gmail.com)
// CREATED: 2013-01-25
// UPDATED: 2013-01-26
//
// Copyright 2010 Song Ho Ahn. All rights reserved.
///////////////////////////////////////////////////////////////////////////////

#import "GroupNameList.h"

@implementation GroupNameList
@synthesize rows;



///////////////////////////////////////////////////////////////////////////////
- (void) add: (NSString*)name
{
    [rows addObject:name];
    //NSLog(@"%@", name);
}



///////////////////////////////////////////////////////////////////////////////
- (void) clear
{
    [rows removeAllObjects];
}



///////////////////////////////////////////////////////////////////////////////
- (id)init
{
    self = [super init];
    if (self)
    {
        rows = [[NSMutableArray alloc] init];
    }
    //printf("GroupNameList.init is called\n");
    return self;
}



///////////////////////////////////////////////////////////////////////////////
// NSTableViewDataSource: return datasource size
- (NSInteger) numberOfRowsInTableView: (NSTableView*)tableView
{
    return [rows count];
}




///////////////////////////////////////////////////////////////////////////////
// NSTableViewDataSource: return the datasource associated row and col
- (id) tableView: (NSTableView*) tableView
 objectValueForTableColumn: (NSTableColumn*)column
                       row: (NSInteger)row
{
    //NSLog(@"%@", [rows objectAtIndex:row]);
    return [rows objectAtIndex:row];
}



///////////////////////////////////////////////////////////////////////////////
// NSTableViewDelegate: retern the view at a certain row and column
- (NSView*) tableView: (NSTableView*)tableView
   viewForTableColumn: (NSTableColumn*)column
                  row: (NSInteger)row
{
    NSTableCellView* cellView = [tableView makeViewWithIdentifier:column.identifier owner:self];
    cellView.textField.stringValue = [rows objectAtIndex:row];
    return cellView;
}





@end
